#
# spec file for package roast
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           roast
Version:        5.1.6
Release:        1.1
Summary:        Simpler tar archiver and extractor
License:        MPL-2.0
URL:            https://github.com/openSUSE-Rust/roast
Source0:        https://github.com/openSUSE-Rust/roast/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(libzstd)

%package -n obs-service-recomprizz
Version:        %{version}
Summary:        OBS Source Service for recomprizz-ion
License:        MPL-2.0

%description -n obs-service-recomprizz
Utility to recompress to other compression formats.

%package -n obs-service-roast
Version:        %{version}
Summary:        OBS Source Service for roast
License:        MPL-2.0

%description -n obs-service-roast
Utility to roast source directories into highly compressed tape archives.

%package -n obs-service-raw
Version:        %{version}
Summary:        OBS Source Service for raw
License:        MPL-2.0

%description -n obs-service-raw
Utility to raw decompress tape archives to unarchived sources.

%description
Roast is a simple tar archiver and extractor with very high
compression settings for supported formats such as zstd.

It also supports recompression from an existing tarball.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
pushd roast-cli
%{cargo_install} --bins
popd
cp -v %{buildroot}%{_bindir}/roast %{buildroot}%{_prefix}/lib/obs/service/roast
install -m0644 roast.service %{buildroot}%{_prefix}/lib/obs/service
cp -v %{buildroot}%{_bindir}/recomprizz %{buildroot}%{_prefix}/lib/obs/service/recomprizz
install -m0644 recomprizz.service %{buildroot}%{_prefix}/lib/obs/service
cp -v %{buildroot}%{_bindir}/raw %{buildroot}%{_prefix}/lib/obs/service/raw
install -m0644 raw.service %{buildroot}%{_prefix}/lib/obs/service

%check
%{cargo_test}

%files
%{_bindir}/roast
%{_bindir}/raw
%{_bindir}/recomprizz
%license LICENCE
%doc     CHANGELOG README.md

%files -n obs-service-roast
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/roast
%{_prefix}/lib/obs/service/roast.service
%license LICENCE
%doc     CHANGELOG README.md

%files -n obs-service-recomprizz
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/recomprizz
%{_prefix}/lib/obs/service/recomprizz.service
%license LICENCE
%doc     CHANGELOG README.md

%files -n obs-service-raw
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/raw
%{_prefix}/lib/obs/service/raw.service
%license LICENCE
%doc     CHANGELOG README.md

%changelog
* Sat Nov  2 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.6:
  * fix: revert 8977c6741364c6d25fb33408d8b4232d835a768b
* Sat Nov  2 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.5:
  * add service files. they serve as documentation
  * fix mismatched types in roast-cli
  * Bump zstd and infer
  * clippy: rectify the needless pass by value
  * chore: set resolver to 2 and enforce strict linting rules
  * fix: just use an empty "" if strip fails
  * add COC and CONTRIBUTING
  * cleanup deps and begin cycle
  * remove comment for 037aa62
  * docs: removed warning. ensured reproducibility.
* Fri Nov  1 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.2:
  * minor: improvements on how we sort files and directories
  * use rayon while you can
  * performance: add rayon to parallelise copying operations
  * docs: add important difference between ADDED and INCLUDED [ci skip]
  * docs: improve wording [ci skip]
  * docs: fix grammar [ci skip]
  * docs: explain how the path behaviour works
  * refactor: improve the logic handling for adding, excluding and including
  * improve message logs
  * fix: resolved some edge-cases with additional paths and included paths
  * fix: reimplement adding of archive files
  * doc: update README on CLI help
  * feat and fix: properly implement exclude and include
  * cli: finalise flags. begin cycle
  * major: begin refactor cycle [ci skip]
  * logging: set to trace level for filter_paths
  * fix: avoid duplicating entries
  * fix: do not consider temporary directory as hidden
  * fix: just use ends_with to check if it's a valid file extension
  * improvement: also filter_paths for each element in additional_paths
  * feat: hidden file and gitignore finally correctly implemented
- New subpackage: obs-service-roast
* Sun Oct 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.5.0:
  * docs: update README and include instructions regarding renaming
  * minor: update tests and update paths code
  * feat: add glob support
  * fix: actually implement the fix for ef1e6f857e48821198d720d092bc7087af762f2a
  * feat: add glob support to all
* Sun Oct 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.2.0:
  * fix: filename should leave out version part alone
* Sun Oct 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.1.0:
  * lib: move over copy_dir_all as a common utility
  * cli: move logic as cli stubs
  * tests: use copy_dir_all as part of lib now instead
  * roast and raw: improve description of cli options then format
  * move raw and roast modules to standalone files
  * cli: add recomprizz args
  * recomprizz: initial implementation
  * import termcap
  * fix: apply clippy lints
  * tracing: set logic where and when to start properly
  * apply clippy lints + format
  * set output path correctly
  * refactor: canonicalize filter
  * refactor: canonicalize paths
  * update deps
  * reproducibility: set to false by default
  * fix: additional paths variable should only be a collection of files and not directories
  * doc: add a warning regarding reproducibility
  * doc: fix warning msg
  * doc: fix warning msg
  * refactor: move mostly to libroast
  * refactor: improve field naming and description
  * refactor: remove tracing crate unused imports
  * minor: raaaaaaaaaaaaawwwwwwww
  * make names consistent
  * remove: cliff.toml and git-cliff is an overengineered changelog generator
  * prepare justfile for publishing
  * change it to a text file
  * cli: allow to explicitly tell "true" or "false" using ArgAction::Set and add our service file
- Add new subpackage `obs-service-recomprizz`
  * This is a possible drop-in replacement for obs-service-recompress
* Sat Oct 19 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 3.3.1:
  * tests: add library tests + ci tests
  * test: this should be two separate files
* Tue Oct 15 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 3.3.0:
  * Properly set preserve root
  * Cleanup raw binary log output
  * Support uncompressed tarballs with tar extension
* Sat Oct 12 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Initial spec for roast 3.2.2
